# Remake the Augsburg's Nibelungenlied TEI corpus

```bash
python nib_scripts.py
```

- nib_retrieval.py
- nib_reader.py
- nib_reformat.py
- nib_scripts.py

## Annotations
* cities
* countries and regions
* peoples
* rivers
